@@ -4,6 +4,7 @@ package Squatting::On::CGI;
 #no  strict 'refs';
 #use warnings;
 use CGI;
+use CGI::Cookie;
 use HTTP::Response;
 
 # p for private
@@ -102,4 +103,19 @@ app.
 Give the C<cgi> method a CGI object, and it will send the apps output to
 STDOUT.
 
+=head1 SEE ALSO
+
+L<CGI>
+
 =cut
+
+# Local Variables: ***
+# mode: cperl ***
+# indent-tabs-mode: nil ***
+# cperl-close-paren-offset: -2 ***
+# cperl-continued-statement-offset: 2 ***
+# cperl-indent-level: 2 ***
+# cperl-indent-parens-as-block: t ***
+# cperl-tab-always-indent: nil ***
+# End: ***
+# vim:tabstop=8 softtabstop=2 shiftwidth=2 shiftround expandtab
